Live updates: Detroit Red Wings vs. Florida Panthers (chat) | MLive.com
Description: The Red Wings, who have won a season-high four in a row, are playing the second of four straight games at Joe Louis Arena.

comments

# Live updates: Detroit Red Wings vs. Florida Panthers (chat)

Darren-Helm-Brian-Lashoff
The Red Wings and Florida Panthers are meeting for the first time this season. (AP Photo)
Print
Aaron McMann | amcmann@mlive.com By Aaron McMann | amcmann@mlive.com MLive.com
Email the author | Follow on Twitter
on December 02, 2014 at 6:30 PM, updated December 02, 2014 at 10:40 PM
View/Post Comments

FREQUENTLY REFRESH this page for the latest. If you're viewing this on our mobile app, click here for updates and to comment.

THIRD PERIOD

Panthers 4, Red Wings 3: Red Wings drop their first since Nov. 22 at Toronto.

Panthers 4, Red Wings 3 (0:58): Gus Nyquists scores on a rebound in front of the net. Jimmy Howard has been pulled for the last two minutes.

Panthers 4, Red Wings 2 (3:23): Tomas Tatar shot skating in from the right side gloved by Luongo. Faceoff in the Florida zone.

Panthers 4, Red Wings 2 (5:18): Detroit whistled for offsides and The Joe begins emptying.

Panthers 4, Red Wings 2 (10:28): Pavel Datsyuk scores with lots of traffic in front of the Florida net. Maybe this game isn't over yet. Detroit still outshooting Florida, 32-29.

Panthers 4, Red Wings 1 (12:00): Detroit musters three shots on the power play but comes away empty. Roberto Luongo takes a Datsyuk shot to the throat, but seems OK. Then, 32 seconds later, Aaron Ekblad scores on a slap shot redirected in front of the net.

Panthers 3, Red Wings 1 (14:32): Jonathan Huberdeau penalized two minutes for tripping. Detroit power play.

Panthers 3, Red Wings 1 (19:33): Vincent Trocheck scores 27 seconds into the third period.

Red Wings-Panthers links:

• Second-period analysis: Panthers 2, Red Wings 1

• First-period analysis: Red Wings 1, Panthers 1

-- Download the Detroit Red Wings on MLive app for iPhone and Android
-- Like MLive's Detroit Red Wings Facebook page

View/Post Comments

## Related Stories

## Detroit Red Wings scoreboard

© 2013 STATS LLC. All rights reserved.

- Standings
- Schedule
- Players

## Standings

## Schedule

## Players

# Detroit Red Wings mobile app

##

## Stay up-to-date on the latest news and scores. Download our mobile app here.

# Red Wings Beat Writers

- Ansar Khan
- Brendan Savage

## Most Read

## Active Discussions

## Best of MLive.com

Historic rise: Great Lakes water levels yet to ...
Owl spotted swimming in Lake Michigan
Welfare drug testing pilot program approved by ...